@@ -4,7 +4,9 @@ use strict;
 use warnings;
 
 use 5.008_005;
-our $VERSION = '0.005';
+our $VERSION = '0.006';
+
+use Carp 'croak';
 
 sub new {
   my $class = shift;
@@ -74,15 +76,7 @@ sub from_tokens {
   );
 }
 
-# overlap is default
-sub from_sets {
-  my ($self, $set1, $set2) = @_;
-
-  # ( A intersect B ) / min(A,B)  
-  return (
-    #$self->intersection($set1,$set2) / $self->min($set1,$set2)
-  );
-}
+sub from_bags { croak 'Method "from_bags" not implemented in subclass' }
 
 sub min {
   (scalar(@{$_[1]}) < scalar(@{$_[2]}))
